@@ -358,7 +358,7 @@ class AsyncSearchClient(NamespacedClient):
         :param allow_partial_search_results: Indicate if an error should be returned
             if there is a partial search failure or timeout
         :param analyze_wildcard: Specify whether wildcard and prefix queries should be
-            analyzed (default: false)
+            analyzed
         :param analyzer: The analyzer to use for the query string
         :param batched_reduce_size: Affects how often partial results become available,
             which happens whenever shard results are reduced. A partial reduction is
@@ -374,7 +374,7 @@ class AsyncSearchClient(NamespacedClient):
             values for field names matching these patterns in the hits.fields property
             of the response.
         :param expand_wildcards: Whether to expand wildcard expression to concrete indices
-            that are open, closed or both.
+            that are open, closed or both
         :param explain: If true, returns detailed information about score computation
             as part of a hit.
         :param ext: Configuration of search extensions defined by Elasticsearch plugins.
@@ -407,7 +407,7 @@ class AsyncSearchClient(NamespacedClient):
             you cannot specify an <index> in the request path.
         :param post_filter:
         :param preference: Specify the node or shard the operation should be performed
-            on (default: random)
+            on
         :param profile:
         :param project_routing: Specifies a subset of projects to target for the search
             using project metadata tags in a subset of Lucene query syntax. Allowed Lucene
